# NavAbilitySDK.py

Access NavAbility Cloud factor graph features from Python.

## Weblinks

Click on the badges to follow web url links:

|  CI  |  Documentation  | caesarjl.slack.com |
|:----:|:---------------:|:------------------:|
| [![Build Status][sdk-py-ci-img]][sdk-py-ci-url] | [![docs][docs-shield]][sdk-py-docs-url] | [![][nva-slack-badge]][nva-slack] |

Note that this SDK and the related API are in beta. Please let us know if you have any issues.

# Installation

Install the NavAbilitySDK using pip:

```bash
pip install navabilitysdk
```

See the Documentation link above for more details.


[sdk-py-docs-url]: https://navability.github.io/NavAbilitySDK.py/
[docs-shield]: https://img.shields.io/badge/docs-latest-blue.svg
[sdk-py-ci-img]: https://github.com/NavAbility/NavAbilitySDK.py/actions/workflows/python-package.yml/badge.svg
[sdk-py-ci-url]: https://github.com/NavAbility/NavAbilitySDK.py/actions/workflows/python-package.yml
[nva-slack-badge]: https://img.shields.io/badge/Invite-Slack-green.svg?style=popout
[nva-slack]: https://join.slack.com/t/caesarjl/shared_invite/zt-ucs06bwg-y2tEbddwX1vR18MASnOLsw